@@ -1,8 +1,5 @@
-#include <stdlib.h>
-#include <stdio.h>
-#include <math.h>
-
 
+#include "matchCount.h"
 
 
 void rMatchCount( 
